<?php

/**
 * @file theme_api.inc
 * General administrative helper functions when working with the theme api
 * form or settings.
 */
// Calls hex_build_settings().
include_once HEX_INCLUDES . '/build_settings.inc';

/**
 * Same as hex_settings but it does not check for parent scopes and it is not
 * cached. This should be used instead of hex_setting() while in
 * hook_form_theme_settings_hex_alter().
 *
 * @see hex_setting()
 */
function hex_themeapi_setting($name = NULL, $default = NULL, $source = HEX_CASCADE) {
  $settings = hex_build_settings(TRUE);

  if ($source === HEX_ACTIVE) {
    $source = hex_active_theme();
  }
  elseif ($source == HEX_CASCADE && !empty($settings->cascade[$name])) {
    $source = $settings->cascade[$name];
  }

  return isset($settings->settings[$source][$name]) ? $settings->settings[$source][$name] : $default;
}

/**
 * Wrap this function for Form API keys that contain dots and colons since it
 * can cause problems.
 * 
 * @param $key
 *  The key.
 * @param $revert
 *  Revert to their original dots and colons.
 */
function hex_fapi_key($key, $revert = FALSE) {
  switch ($revert) {
    // Dot seen as an array "key" and colon for parent conditions or "scope".
    case FALSE : return str_replace(array('.', ':'), array('__key__', '__scp__'), $key);
    case TRUE  : return str_replace(array('__key__', '__scp__'), array('.', ':'), $key);
  }
}

/**
 * Casts strings into constants and integers/floats.
 */
function hex_auto_type($value) {
  if (is_string($value) && is_numeric($value)) {
    $value = ctype_digit($value) ? (int) $value : (float) $value;
  }
  elseif (is_string($value) && defined(strtoupper($value))) {
    $value = constant(strtoupper($value));
  }

  return $value;
}

