<?php

/**
 * @file
 * Theme api settings for Hexagon and any of its child themes.
 */
include_once DRUPAL_ROOT . '/' . hex_path('theme', 'hex') . '/template.php';
include_once DRUPAL_ROOT . '/' . hex_path('theme', 'hex') . '/includes/theme_api.inc';

/**
 * Implements hook_form_system_theme_settings_alter().
 *
 * @see hex_form_theme_settings_alter()
 *
 * Used to work around a core bug.
 * @see http://drupal.org/node/1135794
 */
function hex_form_system_theme_settings_alter(&$form, &$form_state, $form_id = NULL) {

  if (isset($form_id)) {
    return;
  }
  hex_clear_caches();

  $form['#prefix']   = '<div class="theme-summary"></div>';
  $form['#attached'] = array(
    'css' => array(hex_path('theme', 'hex') . '/styles/hex-theme-settings.css'),
  );

  // Anything enabled through the .info will be locked.
  $locked_activation = array();
  foreach (hex_active_themes() as $theme) {
    $locked_activation = array_merge(
      $locked_activation,
      hex_theme_info(hex_active_theme() . '.plugins', array(), $theme),
      hex_theme_info('theme.plugins', array(), $theme)
    );
  }

  // Generate checkboxes for all plug-ins "extensions".
  $plugin_checkboxes = array();
  foreach (hex_plugin_list('all.extension') as $key) {
    if (hex_plugin_exists($key, 'all.active')) {
      $locked_activation = array_merge($locked_activation, hex_plugin_info('requires', array(), $key));
    }
    if (array_diff(hex_plugin_info('module.dependencies', array(), $key), module_list())) {
      $locked_activation[] = $key;
    }
    $plugin_checkboxes[hex_fapi_key("$key.enable")] = array(
      '#type'          => 'checkbox',
      '#title'         => hex_plugin_info('name', 'Untitled', $key),
      '#description'   => hex_plugin_info('description', 'No Description', $key),
      '#default_value' => hex_themeapi_setting("$key.enable", 0, HEX_ACTIVE),
      '#disabled'      => in_array($key, $locked_activation),
    );
  }

  if (!empty($plugin_checkboxes)) {
    $form['plugins'] = array(
      '#title' => t('!theme Plug-ins', array('!theme' => hex_theme_info('name', 'Untitled'))),
      '#type'  => 'fieldset',
    );
    $form['plugins'] += $plugin_checkboxes;
  }

  // Invoke custom alter in a separate namespace due to the double invoke bug.
  // hook_form_system_theme_settings_alter() should only run for actively
  // running themes while hook_form_theme_settings_hex_alter() will run for
  // theme specific forms reguardless of it running or not.
  hex_alter('form_theme_settings', $form, $form_state);

}
